@@ -30,15 +30,17 @@ from pandas_market_calendars.holidays_nyse import (
     SatBeforeWashingtonsBirthdayAdhoc, SatAfterWashingtonsBirthdayAdhoc, 
     SatBeforeAfterLincolnsBirthdayAdhoc,  GrantsBirthDayAdhoc,  
     
-    USMartinLutherKingJrAfter1998, 
-    
+    USMartinLutherKingJrAfter1998,
+
     GoodFriday, GoodFridayPre1898, GoodFriday1899to1905, SatAfterGoodFridayAdhoc,
     
     USMemorialDay, USMemorialDayBefore1952, USMemorialDay1952to1964, USMemorialDay1964to1969,
     SatBeforeDecorationAdhoc, SatAfterDecorationAdhoc,
     DayBeforeDecorationAdhoc,
-    
-    USIndependenceDay, USIndependenceDayPre1952, USIndependenceDay1952to1954,    
+
+    USJuneteenthAfter2022,
+
+    USIndependenceDay, USIndependenceDayPre1952, USIndependenceDay1952to1954,
     SatBeforeIndependenceDayAdhoc, SatAfterIndependenceDayAdhoc,
     MonTuesThursBeforeIndependenceDay, FridayAfterIndependenceDayNYSEpre2013,
     WednesdayBeforeIndependenceDayPost2013,
@@ -802,6 +804,7 @@ class NYSEExchangeCalendar(MarketCalendar):
             ChristmasNYSE,
             Christmas54to98NYSE,
             ChristmasBefore1954,
+            USJuneteenthAfter2022,
         ])
 
     @property
@@ -962,36 +965,44 @@ class NYSEExchangeCalendar(MarketCalendar):
 #
     @property
     def special_closes_adhoc(self):
+        def _union_many(indexes):
+            # Merges a list of pd.DatetimeIndex objects, returns merged DatetimeIndex
+            union_index = pd.DatetimeIndex([], tz="UTC")
+            for index in indexes:
+                union_index = union_index.union(index)
+            return union_index
+
         return [
             (time(13, tzinfo=timezone('America/New_York')),
-              DaysBeforeIndependenceDay1pmEarlyCloseAdhoc # list
+                DaysBeforeIndependenceDay1pmEarlyCloseAdhoc # list
                 + ChristmasEve1pmEarlyCloseAdhoc
                 + DayAfterChristmas1pmEarlyCloseAdhoc
                 + BacklogRelief1pmEarlyClose1929
             ),
-            (time(14, tzinfo=timezone('America/New_York')), pd.DatetimeIndex(
+            (time(14, tzinfo=timezone('America/New_York')), _union_many(
+                [pd.DatetimeIndex(
                  ChristmasEve2pmEarlyCloseAdhoc
-                 + HeavyVolume2pmEarlyClose1933
-                        ).union_many([
-                 BacklogRelief2pmEarlyClose1928,
+                 + HeavyVolume2pmEarlyClose1933)] +
+                                      
+                [BacklogRelief2pmEarlyClose1928,
                  TransitStrike2pmEarlyClose1966, # index
                  Backlog2pmEarlyCloses1967, # index
                  Backlog2pmEarlyCloses1968, # index
                  PaperworkCrisis2pmEarlyCloses1969, # index
                  Backlog2pmEarlyCloses1987 ])# index
             ),
-            (time(14, 30, tzinfo=timezone('America/New_York')), pd.DatetimeIndex([], tz= "UTC"
-                        ).union_many([
-                PaperworkCrisis230pmEarlyCloses1969,
-                Backlog230pmEarlyCloses1987]) # index
+            (time(14, 30, tzinfo=timezone('America/New_York')), _union_many(
+                                      
+                [PaperworkCrisis230pmEarlyCloses1969,
+                 Backlog230pmEarlyCloses1987]) # index
             ),
-            (time(15, tzinfo=timezone('America/New_York')), pd.DatetimeIndex([], tz= "UTC"
-                        ).union_many([
-                PaperworkCrisis3pmEarlyCloses1969to1970,
-                Backlog3pmEarlyCloses1987]) # index
+            (time(15, tzinfo=timezone('America/New_York')), _union_many(
+                                      
+                [PaperworkCrisis3pmEarlyCloses1969to1970,
+                 Backlog3pmEarlyCloses1987]) # index
             ),
             (time(15, 30, tzinfo=timezone('America/New_York')),
-                Backlog330pmEarlyCloses1987 # idnex
+                Backlog330pmEarlyCloses1987 # index
             ),
         ]
 
